/*
 * NXSoundOut.h
 *
 * Interface to sound playback resources.
 *
 * Copyright (c) 1991, NeXT Computer, Inc.  All rights reserved. 
 */

#import "NXSoundDevice.h"

@interface NXSoundOut:NXSoundDevice
{
    unsigned int	_options;
    int			_reserved1;
}

/*
 * Look up the sound-out device port.
 * Returns PORT_NULL if look up fails.
 * Normally only sent by NXSoundDevice -initOnHost.
 */
+ (port_t)lookUpDevicePortOnHost:(const char *)hostName;

/*
 * Get and set options.
 */
- (BOOL)doesInsertZeros;
- (NXSoundDeviceError)setInsertsZeros:(BOOL)flag;
- (BOOL)doesRampUp;
- (NXSoundDeviceError)setRampsUp:(BOOL)flag;
- (BOOL)doesRampDown;
- (NXSoundDeviceError)setRampsDown:(BOOL)flag;
- (BOOL)doesDeemphasize;
- (NXSoundDeviceError)setDeemphasis:(BOOL)flag;
- (BOOL)isSpeakerMute;
- (NXSoundDeviceError)setSpeakerMute:(BOOL)flag;

/*
 * Get clip count.
 */
- (unsigned int)clipCount;

/*
 * Attenuation range is -84 (the most attenuated) dB to 0 dB.
 * It effects the internal speaker and headphone output.
 */
- (NXSoundDeviceError)getAttenuationLeft:(float *)leftDB
                                   right:(float *)rightDB;
- (NXSoundDeviceError)setAttenuationLeft:(float)leftDB
                                   right:(float)rightDB;

@end
